@@ -27,9 +27,7 @@ import sys
 
 import numpy as np
 
-from . import geometry
-from . import data_reduce
-from . import _spatial_mp
+from pyresample import geometry, data_reduce, _spatial_mp
 
 if sys.version < '3':
     range = xrange
@@ -64,7 +62,8 @@ def resample_nearest(source_geo_def, data, target_geo_def,
                      fill_value=0, reduce_data=True, nprocs=1, segments=None):
     """Resamples data using kd-tree nearest neighbour approach
 
-    :Parameters:
+    Parameters
+    ----------
     source_geo_def : object
         Geometry definition of source
     data : numpy array               
@@ -77,7 +76,7 @@ def resample_nearest(source_geo_def, data, target_geo_def,
     epsilon : float, optional
         Allowed uncertainty in meters. Increasing uncertainty
         reduces execution time
-    fill_value : {int, None}, optional 
+    fill_value : int or None, optional
             Set undetermined pixels to this value.
             If fill_value is None a masked array is returned 
             with undetermined pixels masked    
@@ -86,11 +85,12 @@ def resample_nearest(source_geo_def, data, target_geo_def,
         to reduce execution time
     nprocs : int, optional
         Number of processor cores to be used
-    segments : {int, None}
+    segments : int or None
         Number of segments to use when resampling.
         If set to None an estimate will be calculated
 
-    :Returns: 
+    Returns
+    -------
     data : numpy array 
         Source data resampled to target geometry
     """
@@ -106,7 +106,8 @@ def resample_gauss(source_geo_def, data, target_geo_def,
                    fill_value=0, reduce_data=True, nprocs=1, segments=None, with_uncert=False):
     """Resamples data using kd-tree gaussian weighting neighbour approach
 
-    :Parameters:
+    Parameters
+    ----------
     source_geo_def : object
         Geometry definition of source
     data : numpy array               
@@ -134,16 +135,16 @@ def resample_gauss(source_geo_def, data, target_geo_def,
         to reduce execution time
     nprocs : int, optional
         Number of processor cores to be used
-    segments : {int, None}
+    segments : int or None
         Number of segments to use when resampling.
         If set to None an estimate will be calculated
     with_uncert : bool, optional
         Calculate uncertainty estimates
 
-    :Returns:
+    Returns
+    -------
     data : numpy array (default)
         Source data resampled to target geometry
-
     data, stddev, counts : numpy array, numpy array, numpy array (if with_uncert == True)
         Source data resampled to target geometry.
         Weighted standard devaition for all pixels having more than one source value
@@ -185,7 +186,8 @@ def resample_custom(source_geo_def, data, target_geo_def,
                     segments=None, with_uncert=False):
     """Resamples data using kd-tree custom radial weighting neighbour approach
 
-    :Parameters:
+    Parameters
+    ----------
     source_geo_def : object
         Geometry definition of source
     data : numpy array               
@@ -218,10 +220,10 @@ def resample_custom(source_geo_def, data, target_geo_def,
         Number of segments to use when resampling.
         If set to None an estimate will be calculated
 
-    :Returns:
+    Returns
+    -------
     data : numpy array (default)
         Source data resampled to target geometry
-
     data, stddev, counts : numpy array, numpy array, numpy array (if with_uncert == True)
         Source data resampled to target geometry.
         Weighted standard devaition for all pixels having more than one source value
@@ -274,7 +276,8 @@ def get_neighbour_info(source_geo_def, target_geo_def, radius_of_influence,
                        nprocs=1, segments=None):
     """Returns neighbour info
 
-    :Parameters:
+    Parameters
+    ----------
     source_geo_def : object
         Geometry definition of source
     target_geo_def : object
@@ -286,7 +289,7 @@ def get_neighbour_info(source_geo_def, target_geo_def, radius_of_influence,
     epsilon : float, optional
         Allowed uncertainty in meters. Increasing uncertainty
         reduces execution time
-    fill_value : {int, None}, optional 
+    fill_value : int or None, optional
             Set undetermined pixels to this value.
             If fill_value is None a masked array is returned 
             with undetermined pixels masked    
@@ -295,11 +298,12 @@ def get_neighbour_info(source_geo_def, target_geo_def, radius_of_influence,
         to reduce execution time
     nprocs : int, optional
         Number of processor cores to be used
-    segments : {int, None}
+    segments : int or None
         Number of segments to use when resampling.
         If set to None an estimate will be calculated
 
-    :Returns:
+    Returns
+    -------
     (valid_input_index, valid_output_index, 
     index_array, distance_array) : tuple of numpy arrays
         Neighbour resampling info
@@ -543,9 +547,10 @@ def _query_resample_kdtree(resample_kdtree, source_geo_def, target_geo_def,
 
     # pykdtree requires query points have same data type as kdtree.
     try:
-        dt = resample_kdtree.data_pts.dtype
-    except AttributeError:
         dt = resample_kdtree.data.dtype
+    except AttributeError:
+        # use a sensible default
+        dt = np.dtype('d')
     output_coords = np.asarray(output_coords, dtype=dt)
 
     # Query kd-tree
@@ -580,7 +585,8 @@ def get_sample_from_neighbour_info(resample_type, output_shape, data,
                                    with_uncert=False):
     """Resamples swath based on neighbour info
 
-    :Parameters:
+    Parameters
+    ----------
     resample_type : {'nn', 'custom'}
         'nn': Use nearest neighbour resampling
         'custom': Resample based on weight_funcs
@@ -603,12 +609,13 @@ def get_sample_from_neighbour_info(resample_type, output_shape, data,
         If only one channel is resampled weight_funcs is
         a single function object.
         Must be supplied when using 'custom' resample type
-    fill_value : {int, None}, optional 
+    fill_value : int or None, optional
         Set undetermined pixels to this value.
         If fill_value is None a masked array is returned 
         with undetermined pixels masked
 
-    :Returns: 
+    Returns
+    -------
     result : numpy array 
         Source data resampled to target geometry
     """
