@@ -1,22 +1,14 @@
 from __future__ import with_statement
 
 import sys
-import unittest
-
 import numpy as np
-
-import warnings
-if sys.version_info < (2, 6):
-    warnings.simplefilter("ignore")
-else:
-    warnings.simplefilter("always")
-
+from pyresample.test.utils import catch_warnings
 from pyresample import geometry, geo_filter
 
-
-def tmp(f):
-    f.tmp = True
-    return f
+if sys.version_info < (2, 7):
+    import unittest2 as unittest
+else:
+    import unittest
 
 
 class Test(unittest.TestCase):
@@ -68,7 +60,6 @@ class Test(unittest.TestCase):
         self.assertAlmostEqual(lat, 52.566998432390619,
                                msg='lat retrieval from precomputated grid failed')
 
-    @tmp
     def test_cartesian(self):
         area_def = geometry.AreaDefinition('areaD', 'Europe (3km, HRV, VTC)', 'areaD',
                                            {'a': '6378144.0',
@@ -102,13 +93,13 @@ class Test(unittest.TestCase):
         lons1 = np.arange(-135., +135, 50.)
         lats = np.ones_like(lons1) * 70.
 
-        with warnings.catch_warnings(record=True) as w1:
+        with catch_warnings() as w1:
             base_def1 = geometry.BaseDefinition(lons1, lats)
             self.assertFalse(
                 len(w1) != 0, 'Got warning <%s>, but was not expecting one' % w1)
 
         lons2 = np.where(lons1 < 0, lons1 + 360, lons1)
-        with warnings.catch_warnings(record=True) as w2:
+        with catch_warnings() as w2:
             base_def2 = geometry.BaseDefinition(lons2, lats)
             self.assertFalse(
                 len(w2) != 1, 'Failed to trigger a warning on longitude wrapping')
@@ -118,7 +109,7 @@ class Test(unittest.TestCase):
         self.assertFalse(
             base_def1 != base_def2, 'longitude wrapping to [-180:+180] did not work')
 
-        with warnings.catch_warnings(record=True) as w3:
+        with catch_warnings() as w3:
             base_def3 = geometry.BaseDefinition(None, None)
             self.assertFalse(
                 len(w3) != 0, 'Got warning <%s>, but was not expecting one' % w3)
@@ -145,7 +136,7 @@ class Test(unittest.TestCase):
 
         # Test dtype is preserved with automatic longitude wrapping
         lons2 = np.where(lons1 < 0, lons1 + 360, lons1)
-        with warnings.catch_warnings(record=True) as w:
+        with catch_warnings() as w:
             basedef = geometry.BaseDefinition(lons2, lats)
 
         lons, _ = basedef.get_lonlats()
@@ -154,7 +145,7 @@ class Test(unittest.TestCase):
                          (lons2.dtype, lons.dtype,))
 
         lons2_ints = lons2.astype('int')
-        with warnings.catch_warnings(record=True) as w:
+        with catch_warnings() as w:
             basedef = geometry.BaseDefinition(lons2_ints, lats)
 
         lons, _ = basedef.get_lonlats()
@@ -180,16 +171,12 @@ class Test(unittest.TestCase):
             lambda y, x: 75 - (50.0 / 5000) * y, (5000, 100))
 
         lons1 += 180.
-        if (sys.version_info < (2, 6) or
-                (sys.version_info >= (3, 0) and sys.version_info < (3, 4))):
+        with catch_warnings() as w1:
             swath_def = geometry.BaseDefinition(lons1, lats1)
-        else:
-            with warnings.catch_warnings(record=True) as w1:
-                swath_def = geometry.BaseDefinition(lons1, lats1)
-                self.assertFalse(
-                    len(w1) != 1, 'Failed to trigger a warning on longitude wrapping')
-                self.assertFalse(('-180:+180' not in str(w1[0].message)),
-                                 'Failed to trigger correct warning about longitude wrapping')
+            self.assertFalse(
+                len(w1) != 1, 'Failed to trigger a warning on longitude wrapping')
+            self.assertFalse(('-180:+180' not in str(w1[0].message)),
+                             'Failed to trigger correct warning about longitude wrapping')
 
         lons2, lats2 = swath_def.get_lonlats()
 
@@ -541,7 +528,6 @@ class Test(unittest.TestCase):
                                122.06448093539757, 5,
                                'Failed to get lon and lats of area extent')
 
-    @tmp
     def test_latlong_area(self):
         area_def = geometry.AreaDefinition('', '', '',
                                            {'proj': 'latlong'},
@@ -551,9 +537,7 @@ class Test(unittest.TestCase):
         self.assertEqual(lons[0, 0], -179.5)
         self.assertEqual(lats[0, 0], 89.5)
 
-
     def test_lonlat2colrow(self):
-
         from pyresample import utils
         area_id = 'meteosat_0deg'
         area_name = 'Meteosat 0 degree Service'
